@@ -189,20 +189,21 @@
 (define (TweakOffset grob tag offsetx offsety)
     (define sa-tag (d-DirectiveGetForTag-standalone ""))
     (if sa-tag      
-        (let ((grob (d-DirectiveGet-standalone-grob sa-tag))) ;;; FIXME can we just use the passed in grob
+        (let ()
                 (if grob
                     (cond ((or (equal? grob "RehearsalMark") (equal? grob "BreathingSign")   (equal? grob "MetronomeMark")    )
-                            (ExtraOffset sa-tag sa-tag "standalone" "Score." (cons offsetx offsety)))
+                            (ExtraOffset sa-tag grob "standalone" "Score." (cons offsetx offsety)))
                         (#t
                             (TweakRelativeOffset sa-tag offsetx offsety)))
                     (TweakRelativeOffset sa-tag offsetx offsety)))
         ;;; not a standalone directive              
         (begin
-      ;;(if (equal? grob "BassFigure")
-        ;;(d-AdjustBassFigureHeight offsety))
-        
             (if tag
-                (eval-string (string-append "(d-" tag "  (list (cons 'offsetx \"" offsetx "\")  (cons 'offsety \"" offsety "\")))")))
+              (if (defined? (string->symbol (string-append "d-" tag)))
+                (eval-string (string-append "(d-" tag "  (list (cons 'offsetx \"" offsetx "\")  (cons 'offsety \"" offsety "\")))"))                
+                (eval-string (string-append "(d-ToggleCustomOrnament (list \"" tag "\" (cons 'offsetx \"" offsetx "\")  (cons 'offsety \"" offsety "\")))"))))
+                
+                
             (if (Rest?)
                 (ExtraOffset "RestOffset" "Rest" "chord" "Voice." (cons offsetx offsety) DENEMO_OVERRIDE_AFFIX)
                 (if (equal? grob "BassFigure")
@@ -404,13 +405,24 @@ To do this dismiss this dialog and guess at where the red spot is on the object.
         (let ((direction #f)
                 (choice #f)
                 (menu (list (cons (_ "Up")  "^")  (cons (_ "Down")  "_") (cons (_ "Auto")  "-") )) )
-                         (set! choice (d-PopupMenu menu))
-                          (if choice
-                                (eval-string (string-append "(d-" tag " (list (cons 'direction \"" choice "\")))")))))
+            (set! choice (d-PopupMenu menu))
+            (if choice
+                (begin
+                    (if (defined? (string->symbol (string-append "d-" tag)))
+                        (eval-string (string-append "(d-" tag " (list (cons 'direction \"" choice "\")))"))
+                        (eval-string (string-append "(d-ToggleCustomOrnament (list \"" tag "\" (cons 'direction \"" choice "\")))")))))))
+                                    
+                                    
     
   (define (do-padding)
-        (let ((padding (d-GetUserInput (_ "Padding") (_ "Give amount of padding required around this item (in staff spaces)") "2")))
-                                (eval-string (string-append "(d-" tag " (list (cons 'padding \"" padding "\")))"))))
+        (let ((padding (d-GetUserInput (_ "Padding") (_ "Give amount of padding required around this item (in staff spaces)") "0.5")))
+        (if padding
+                (begin
+                    (if (defined? (string->symbol (string-append "d-" tag)))
+                                (eval-string (string-append "(d-" tag " (list (cons 'padding \"" padding "\")))"))
+                                (eval-string (string-append "(d-ToggleCustomOrnament (list \"" tag "\" (cons 'padding \"" padding "\")))")))))))
+                                
+                                
                             
                             
     (define (alter-text)
@@ -457,7 +469,7 @@ To do this dismiss this dialog and guess at where the red spot is on the object.
                                 ;;; FIXME the value is relative to the centre line of the staff, this gets relative to the tr sign.
                                 ;;;need to use d-GetNewTarget to find the notehead position, then use its mid_c_offset to get the centre line value
                                 ;;; beaming does this
-                                
+                           
                                 
                                 (set! choice (d-PopupMenu menu))
                                 (if choice
@@ -551,28 +563,34 @@ To do this dismiss this dialog and guess at where the red spot is on the object.
                                                             ((equal? choice (_ "Auto")) "-")))
                     (d-DirectivePut-chord-postfix tag (string-append  (string-append choice " " lilypond " ")))
                     (d-SetSaved #f)))))
-  
     (if (and (d-Directive-chord? tag) (equal? params "edit"))
-                        (case (GetEditOption)
-                                ((edit) (direction-edit))
-                                ((cancel) #f)
-                                ((advanced) (d-DirectiveTextEdit-chord tag))
-                                ((delete) (d-DirectiveDelete-chord tag))
-                                (else #f))
-                        (if params
-                            (begin 
-                                (if (and (d-Directive-chord? tag) (list? params))
+        (case (GetEditOption)
+            ((edit) (direction-edit))
+            ((cancel) #f)
+            ((advanced) (d-DirectiveTextEdit-chord tag))
+            ((delete) (d-DirectiveDelete-chord tag))
+            (else #f))
+        (if params
+            (begin 
+                    (if (and (d-Directive-chord? tag) (list? params))
                                     (begin
                                         (d-SetSaved #f)
-                    (set! current-direction (substring (string-trim (d-DirectiveGet-chord-postfix tag)) 0 1))
+                                        (set! current-direction (substring (string-trim (d-DirectiveGet-chord-postfix tag)) 0 1))
                                         (d-DirectivePut-chord-postfix tag (string-append  (string-join (map set-option params)) " " lilypond " ")))
                                     (d-WarningDialog "Cannot complete operation - cursor moved or bad parameter list")))
-                            (begin  ;;;no parameters, toggle annotation off/on
+            (begin  ;;;no parameters, toggle annotation off/on
+                    (ToggleChordDirective tag graphic lilypond DENEMO_OVERRIDE_ABOVE display)))))
                                             
-                                            (ToggleChordDirective tag graphic lilypond DENEMO_OVERRIDE_ABOVE display)))))
-                                            
-                                            
-                                                                
+(define* (ChordOrnament tag lilypond params graphic #:optional display)
+       (ChordAnnotation tag lilypond params graphic display))  
+;       (ChordAnnotation tag (string-append "-\\tweak outside-staff-priority #50 " lilypond) params graphic display))  
+;        (if (d-Directive-chord? tag)
+;           (let ((priotag (string-append "Priority" tag)))
+;                (d-DirectivePut-chord-prefix priotag "\\once \\override TextScript.outside-staff-priority = #50 ")
+;                (d-DirectivePut-chord-override priotag DENEMO_OVERRIDE_AFFIX))
+;            (d-DirectiveDelete-chord priotag)))
+
+
 ; SetSlurPositions
 (define (SetSlurPositions near far)
     (d-DirectivePut-chord-override "Slur" DENEMO_OVERRIDE_AFFIX)
