@@ -171,7 +171,7 @@
     (define (doublestroke::invokegui)
         (if gui-version
              (gui-version)
-             (begin FallBack ; create a gui from the given parameters, test for cancel-button #f
+             (begin ;FallBack ; create a gui from the given parameters, test for cancel-button #f
                 (set! gui-version (apply RadioBoxMenu (delete (cons "" False) 
                     (list first second third fourth fifth sixth seventh eighth ninth tenth 
 
@@ -541,11 +541,14 @@
 ;;;;;;;;;;;;;;;;;;;;;;;;
 
 (define (DenemoPrintAllHeaders)
-  (if (or (d-Directive-score? "LilyPondInclude:book-titling.ily") (d-Directive-score? "LilyPondInclude:simplified-book-titling.ily"))
+    (d-LilyPondInclude (cons 'query "book-titling.ily"))
+    (if (not LilyPondInclude::return)
+        (d-LilyPondInclude (cons 'query "simplified-book-titling.ily")))
+  (if LilyPondInclude::return
     (begin
-      (d-WarningDialog "You had book titles for this score. These are being dropped. To re-instate them, re-set the title as a book title.")
-      (d-DirectiveDelete-score "LilyPondInclude:book-titling.ily")
-      (d-DirectiveDelete-score "LilyPondInclude:simplified-book-titling.ily")))
+      (d-WarningDialog (_ "You had book titles for this score. These are being dropped. To re-instate them, re-set the title as a book title."))
+      (d-LilyPondInclude (cons 'delete "book-titling.ily"))
+      (d-LilyPondInclude (cons 'delete "simplified-book-titling.ily"))))
   (d-DirectivePut-paper-postfix "PrintAllHeaders" "\nprint-all-headers = ##t\n"))
      
 (define* (SetQuarterCommaMeanTone #:optional (thestep 0))
@@ -923,3 +926,17 @@
     (d-DirectivePut-standalone-grob tag "Text")
     (d-DirectivePut-standalone-display tag text)
     (d-DirectivePut-standalone-minpixels tag 30))
+;;;;;;;;    
+(define (GetLilyPondDirection)
+    (RadioBoxMenu (cons (_ "Up") "^") (cons (_ "Down") "_") (cons (_ "Auto") "-")))
+;;;;
+(define (CheckForLilyPondDefine name)
+    (if (d-Directive-score? (string-append "Allow\n" name))
+        #t
+        (let ((filename
+            (string-append DENEMO_LOCAL_ACTIONS_DIR "//graphics//" name ".eps")))
+            (if (d-FileExists filename)
+                (d-CustomOrnamentDefinition (list name filename 2))
+                #f))))
+                
+                
