@@ -7,6 +7,6 @@
 Denemo
 48")
 
-(d-DirectivePut-chord-prefix "WholeMeasureRepeat" "\\override MultiMeasureRest #'stencil  = #ly:multi-measure-rest::percent  \\override MultiMeasureRest #'thickness = #0.48 ")
+(d-DirectivePut-chord-prefix "WholeMeasureRepeat" "\\once \\override MultiMeasureRest #'extra-offset = #'(0 . -1)  \\override MultiMeasureRest #'stencil  = #ly:multi-measure-rest::percent  \\override MultiMeasureRest #'thickness = #0.48 ")
 (d-SetSaved #f)
 ;;;End of scheme script
\ No newline at end of file
