@@ -2,6 +2,7 @@
 (define-once Transpose::Interval #f)
 (let ((transpose "Transpose")(cancel "Cancel") (instruction (_ "⬅Edit the interval and click Transpose button above")))
     (d-NewWindow)
+    (d-HideMenus)
     (if  (string? Transpose::Interval)
         (let ((thenotes (string-split Transpose::Interval #\space)))
             (d-Insert2)
@@ -24,10 +25,16 @@
             (set! interval (string-append interval \" \" (d-GetNote)))
             (d-SetSaved #t)
             (d-Close)
+            (d-HideMenus #f)
+             (d-ToggleReduceToDrawingArea)
+            (d-ToggleReduceToDrawingArea)
             (d-TransposeScorePrint interval))"
         )
         
     (CreateButton cancel (string-append " <span font_desc=\"36\" foreground=\"black\">" (_ "Cancel")"</span>"))
     (d-SetDirectiveTagActionScript cancel 
         " (d-SetSaved #t)
-            (d-Close)"))
\ No newline at end of file
+            (d-Close)
+             (d-HideMenus #f)
+            (d-ToggleReduceToDrawingArea)
+            (d-ToggleReduceToDrawingArea)"))
\ No newline at end of file
