@@ -292,6 +292,7 @@ typedef struct
 
   gint volume;  /**< Master Volume used to scale midi playback */
   gboolean override_volume; /**< when true staff plays full Volume always */
+  gboolean mute;/**< when true mutes regardless of override_volume */
   /* Back to Hiller stuff */
   //  GString *staff_name;
 
@@ -419,7 +420,7 @@ typedef struct DenemoPrefs
 
   GString *profile; /**< Which set of commands and shortcuts to load, and which initialization of scheme to run */
   GString *lilypath; /**< This is the executable or full path to the lilypond executable */
-  GString *audioplayer; /**< This is used for playing audio files*/
+  GString *graphicseditor; /**< editing eps graphics files */
   GString *fontspec; /**< Font specification usually Denemo as this has the required characters */
   gboolean manualtypeset;/**< typeset on request, not continuously */
   gint typesetrefresh;/**< ms between re-trying typeset */
