@@ -454,6 +454,7 @@ swapmovements (G_GNUC_UNUSED GtkAction * action, G_GNUC_UNUSED DenemoScriptParam
       this->prev = prevv;
       prev->next = next;
       prev->prev = this;
+      set_movement_selector (gui);
       gchar *str = g_strdup_printf (_("This movement is now number %d in the score"), 1 + g_list_index (gui->movements, gui->movement));
       infodialog (str);
       g_free (str);
@@ -2798,7 +2799,7 @@ auto_save_document_timeout (DenemoProject * gui)
   /* first check that this timer has not been left running after destruction of the gui */
   if (g_list_find (Denemo.projects, gui) == NULL)
     {
-      warningdialog (_("Timer left running"));
+      //do not do this, it causes denemo to hang. warningdialog (_("Timer left running"));
       return FALSE;             /* turns off the timer */
     }
   DenemoMovement *si = gui->movement;
