@@ -80,6 +80,8 @@ void set_movement_selector (DenemoProject *gui)
 
   if(Denemo.non_interactive)
     return;
+    
+
   
   if(gui->movements_selector)
       gtk_widget_destroy (gui->movements_selector);
@@ -147,7 +149,7 @@ void set_movement_selector (DenemoProject *gui)
     
    
     if ((gui->movement) && gui->movement->lyricsbox && Denemo.prefs.lyrics_pane)
-      gtk_widget_show (gui->movement->lyricsbox);
+      g_print("Showing\n"), gtk_widget_show (gui->movement->lyricsbox);
     
   
 }
