@@ -113,6 +113,7 @@ command_row_init(command_row *command)
   command->after = NULL;
   command->fallback = NULL;
   command->menupath = NULL;
+  command->scheme = NULL;
 }
 
 command_row*
@@ -905,7 +906,25 @@ lookup_command_for_keybinding_name (keymap * the_keymap, const gchar * binding_n
     return -1;
 }
 
+/**
+ * get_scheme_from_idx:
+ * @idx: The command id.
+ *
+ * Returns null if idx is not valid.
+ * Loads the scheme code if it is not yet loaded, and caches it.
+ * Finally returns the scheme code, or NULL if the command is builtin.
+ **/
 
+gchar*
+get_scheme_from_idx (gint idx){
+  command_row* row = g_hash_table_lookup(Denemo.map->commands, &idx);
+  if(!row)
+    return NULL;
+  if(row->scheme)
+    return row->scheme;
+  row->scheme = load_command_data (idx);
+  return row->scheme;
+}
 
 /**
  * Look up for a command index.
@@ -1021,13 +1040,12 @@ lookup_label_from_idx (keymap * keymap, gint command_id)
 const gchar *
 lookup_menu_path_from_idx (keymap * keymap, gint command_id)
 {
-    gchar *menupath = NULL;
-    if (command_id == -1)
-        return NULL;
-  GtkAction *action = (GtkAction *) lookup_action_from_idx (keymap, command_id);
-    if (action)
-        menupath = g_object_get_data (G_OBJECT (action), "menupath");
-    return menupath;
+  command_row* row = NULL;
+  keymap_get_command_row(Denemo.map, &row, command_id);
+  if(row)
+    return row->menupath;
+  g_critical ("No row for command number %d\n", command_id);
+  return NULL;
 }
 //returns the accel, "" if no accel defined. free the result
 //the accel is the first keybinding of the list
@@ -1070,6 +1088,8 @@ findActionGroupByName (gconstpointer a, gconstpointer b)
 void
 update_accel_labels (keymap * the_keymap, guint command_id)
 {
+  if(Denemo.non_interactive)
+    return;
   GtkAction *action;
   command_row *row;
 
@@ -1454,11 +1474,17 @@ execute_callback_from_idx (keymap * the_keymap, guint command_id)
 gboolean
 execute_callback_from_name (const gchar * command_name)
 {
-  gchar *text = NULL;
+  gint idx = lookup_command_from_name(Denemo.map, command_name);
   GtkAction *action = lookup_action_from_name ((gchar *) command_name);
-  text = (gchar *) g_object_get_data (G_OBJECT (action), "scheme");
-  if (text && *text)
-    call_out_to_guile (text);
+  gboolean builtin = is_action_name_builtin((gchar*) gtk_action_get_name(action));
+  
+  if (!builtin){
+    gchar* text = get_scheme_from_idx (idx);
+    if(text)
+      call_out_to_guile (text);
+    else
+      gtk_action_activate (action);
+  }
   else
     gtk_action_activate (action);
   return TRUE;
@@ -2159,7 +2185,7 @@ keymap_change_binding_view_on_command_selection (GtkTreeSelection * selection, G
   if (tooltip)
     {
       gchar *plain;
-      gchar *menupath = get_menu_position (g_object_get_data (G_OBJECT (action), "menupath"));
+      gchar *menupath = get_menu_position (row->menupath);
       
       gchar *text = g_strdup_printf (_( "%s\nLocation: %s\nInternal Name: %s"), tooltip, menupath, gtk_action_get_name(action));
       pango_parse_markup (text, -1, 0, NULL, &plain, 0, NULL);
