@@ -46,12 +46,9 @@ static gint file_import_midi (DenemoProject * gui, DenemoSaveType template, Impo
 static gint file_import_musicxml (DenemoProject * gui, DenemoSaveType template, ImportType type, gchar * filename);
 static gboolean replace_existing_file_dialog (const gchar * filename, gint format_id);
 
-
-
-
-
 typedef enum
-{ DENEMO_FORMAT = 0,
+{ 
+  DENEMO_FORMAT = 0,
   DNM_FORMAT,
   MUDELA_FORMAT,
   PDF_FORMAT,
@@ -71,37 +68,57 @@ struct FileFormatData
   gboolean async;               /* TRUE if uses async */
 };
 
-static struct FileFormatData supported_file_formats[] = {       /* WARNING this array has to match the FileFormatNames enum above which is used to index it!!!!!!!!!" */
-  {"*.denemo", N_("Denemo XML format (*.denemo)"), ".denemo", 0},
-  {"*.dnm", N_("Denemo XML format (*.dnm)"), ".dnm", 0},
-  {"*.ly", N_("Lilypond (*.ly)"), ".ly", 0},
-  {"*.pdf", N_("PDF (*.pdf)"), ".pdf", 1},
-  {"*.png", N_("PNG Image format (*.png)"), ".png", 1},
-  {"*.abc", N_("ABC (*.abc)"), ".abc", 0},
-  {"*.mid", N_("Midi (*.mid, *.midi)"), ".mid", 0},
-  {"*.sco", N_("CSound Score File (*.sco)"), ".sco", 0},
-  {"*.mxml", N_("MusicXML file (*.mxml, *.xml)"), ".mxml", 0}
+/* WARNING this array has to match the FileFormatNames enum above which is used to index it!!!!!!!!!" */
+static struct FileFormatData supported_file_formats[] = {
+  {"*.denemo", N_("Denemo XML format (*.denemo)"),  ".denemo", 0},
+  {"*.dnm",    N_("Denemo XML format (*.dnm)"),     ".dnm", 0},
+  {"*.ly",     N_("Lilypond (*.ly)"),               ".ly", 0},
+  {"*.pdf",    N_("PDF (*.pdf)"),                   ".pdf", 1},
+  {"*.png",    N_("PNG Image format (*.png)"),      ".png", 1},
+  {"*.abc",    N_("ABC (*.abc)"),                   ".abc", 0},
+  {"*.mid",    N_("Midi (*.mid, *.midi)"),          ".mid", 0},
+  {"*.sco",    N_("CSound Score File (*.sco)"),     ".sco", 0},
+  {"*.mxml",   N_("MusicXML file (*.mxml, *.xml)"), ".mxml", 0}
 };
 
-static gchar *supported_denemo_file_extension[] = {
-  "*.denemo", "*.DENEMO"
-};
+static GList*
+supported_file_extensions(gchar* format){
+  GList* exts = NULL;
+  
+  if(g_strcmp0 ("denemo", format) == 0){
+    exts = g_list_append(exts, "*.denemo");
+    exts = g_list_append(exts, "*.DENEMO");
+  }
+  
+  if(g_strcmp0 ("lilypond", format) == 0){
+    exts = g_list_append(exts, "*.ly");
+    exts = g_list_append(exts, "*.LY");
+  }
+  
+  if(g_strcmp0 ("midi", format) == 0){
+    exts = g_list_append(exts, "*.midi");
+    exts = g_list_append(exts, "*.mid");
+    exts = g_list_append(exts, "*.MIDI");
+    exts = g_list_append(exts, "*.MID");
+  }  
+  
+  if(g_strcmp0 ("musicxml", format) == 0){
+    exts = g_list_append(exts, "*.mxml");
+    exts = g_list_append(exts, "*.MXML");
+    exts = g_list_append(exts, "*.xml");
+  }
+  
+  if(g_strcmp0 ("pdf", format) == 0){
+    exts = g_list_append(exts, "*.pdf");
+    exts = g_list_append(exts, "*.PDF");
+  }
+  if(g_strcmp0 ("evince", format) == 0){
+    exts = g_list_append(exts, "*.pdf");
+    exts = g_list_append(exts, "*.PDF");
+  }
 
-static gchar *supported_lilypond_file_extension[] = {
-  "*.ly", "*.LY"
-};
-
-static gchar *supported_midi_file_extension[] = {
-  "*.midi", "*.mid", "*.MIDI", "*.MID"
-};
-
-static gchar *supported_musicxml_file_extension[] = {
-  "*.mxml", "*.MXML", "*.xml"
-};
-
-static gchar *supported_evince_file_extension[] = {
-  "*.pdf", "*.PDF"
-};
+  return exts;
+}
 
 /* Some macros just to shorten lines */
 #define FORMAT_MASK(i) supported_file_formats[i].filename_mask
@@ -630,20 +647,18 @@ template_open (DenemoProject * gui, TemplateType local, gchar * filename)
   return ret;
 }
 
-#define OPEN_WITH_CHECK(dir) \
-GET_1PARAM(action, param, filename); \
-  DenemoProject *gui = Denemo.project; \
-  if (gui->notsaved) \
-    { \
-      if (filename==NULL && confirmbox (gui)) \
-    { \
-      param->status = !template_open (gui, dir, filename); \
-    } \
-    } \
-  else \
-    { \
-      param->status = !template_open (gui, dir, filename); \
+static void
+open_with_check(TemplateType dir, GtkAction * action, DenemoScriptParam * param){
+  GET_1PARAM(action, param, filename);
+  if (Denemo.project->notsaved){
+    if (filename==NULL && confirmbox (Denemo.project)){
+      param->status = !template_open (Denemo.project, dir, filename);
     }
+  }
+  else{
+    param->status = !template_open (Denemo.project, dir, filename);
+  }
+}
 
 /*
  * Open system template file callback function 
@@ -651,7 +666,8 @@ GET_1PARAM(action, param, filename); \
 void
 system_template_open_with_check (GtkAction * action, DenemoScriptParam * param)
 {
-OPEN_WITH_CHECK (SYSTEM)}
+  open_with_check (SYSTEM, action, param);
+}
 
 /*
  * Open system template file callback function 
@@ -659,7 +675,8 @@ OPEN_WITH_CHECK (SYSTEM)}
 void
 system_example_open_with_check (GtkAction * action, DenemoScriptParam * param)
 {
-OPEN_WITH_CHECK (EXAMPLE)}
+  open_with_check (EXAMPLE, action, param);
+}
 
 /*
  * Open local template file callback function 
@@ -667,7 +684,8 @@ OPEN_WITH_CHECK (EXAMPLE)}
 void
 local_template_open_with_check (GtkAction * action, DenemoScriptParam * param)
 {
-OPEN_WITH_CHECK (LOCAL)}
+  open_with_check (LOCAL, action, param);
+}
 
 /**
  * Wrapper function for opening a file, d-Open
@@ -692,14 +710,12 @@ file_open_with_check (GtkAction * action, DenemoScriptParam * param)
     }
 }
 
-#define IMPORT(import_type)  \
-  GET_1PARAM(action, param, filename); \
-  param->status = !file_import_##import_type (Denemo.project, FALSE, REPLACE_SCORE, filename);
-
 void
 file_import_lilypond_with_check (GtkAction * action, DenemoScriptParam * param)
 {
-IMPORT (lilypond)}
+  GET_1PARAM(action, param, filename);
+  param->status = !file_import_lilypond (Denemo.project, FALSE, REPLACE_SCORE, filename);
+}
 
 void
 file_import_midi_with_check (GtkAction * action, DenemoScriptParam * param)
@@ -714,14 +730,15 @@ file_import_midi_with_check (GtkAction * action, DenemoScriptParam * param)
 void
 file_import_musicxml_with_check (GtkAction * action, DenemoScriptParam * param)
 {
-IMPORT (musicxml)}
+  GET_1PARAM(action, param, filename);
+  param->status = !file_import_musicxml (Denemo.project, FALSE, REPLACE_SCORE, filename);
+}
 
 #define ADD(insertion_strategy)\
-  DenemoProject *gui = Denemo.project;\
   GET_1PARAM(action, param, filename);\
-  (void)signal_structural_change(gui);\
-  param->status = !file_open(gui, FALSE, insertion_strategy, filename);\
-  score_status(gui, TRUE);\
+  (void)signal_structural_change(Denemo.project);\
+  param->status = !file_open(Denemo.project, FALSE, insertion_strategy, filename);\
+  score_status(Denemo.project, TRUE);\
 
 /**
  * Wrapper function for opening a file to add movements to the current score
@@ -818,54 +835,56 @@ update_preview_cb (GtkFileChooser * file_chooser, gpointer data)
 #endif
 }
 
-
-#define FILE_OPEN_DIALOG(message, format, save_type) \
-  gboolean ret = -1;\
-  if(filename && !g_file_test(filename, G_FILE_TEST_IS_DIR))\
-    return (open_for_real(filename, gui, template, type));\
-  \
-  GtkWidget *file_selection;\
-  GtkFileFilter *filter;\
-  gint i;\
-  \
-  file_selection = gtk_file_chooser_dialog_new (_(message),\
-                        GTK_WINDOW (Denemo.window),\
-                        GTK_FILE_CHOOSER_ACTION_OPEN,\
-                        GTK_STOCK_CANCEL,\
-                        GTK_RESPONSE_REJECT,\
-                        GTK_STOCK_OPEN,\
-                        GTK_RESPONSE_ACCEPT, NULL);\
-  /* Open the last visited directory, if any. */\
-  set_current_folder(file_selection, template);\
-  \
-  filter = gtk_file_filter_new ();\
-  gtk_file_filter_set_name (filter, FORMAT_DESCRIPTION(save_type));\
-  \
-  for (i = 0; i < (gint) G_N_ELEMENTS (supported_##format##_file_extension); i++)\
-    gtk_file_filter_add_pattern (filter, supported_##format##_file_extension[i]); \
-  gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (file_selection), filter);\
-  gtk_dialog_set_default_response (GTK_DIALOG (file_selection),\
-                   GTK_RESPONSE_ACCEPT);\
-  gtk_widget_show_all (file_selection);\
-  GtkWidget *preview;\
-  preview = gtk_image_new();\
-  gtk_file_chooser_set_preview_widget(GTK_FILE_CHOOSER (file_selection), preview);\
-  g_signal_connect (GTK_FILE_CHOOSER(file_selection), "update-preview",\
-            G_CALLBACK (update_preview_cb), preview);\
-  gtk_widget_show_all (preview);\
-  if (gtk_dialog_run (GTK_DIALOG (file_selection)) == GTK_RESPONSE_ACCEPT)\
-    {\
-      gchar *name =\
-    gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (file_selection));\
-      if((ret=open_for_real (name, gui, template, type))) {\
-    gchar *warning = g_strdup_printf(_("Load of file %s failed"), name);\
-    warningdialog(warning);\
-    g_free(warning);\
-      }\
-      g_free (name);\
-    }\
-  gtk_widget_destroy (file_selection);\
-  return ret;\
+static gboolean
+file_open_dialog(gchar* message, gchar* format, FileFormatNames save_type, DenemoSaveType template, ImportType type, gchar* filename){
+  gboolean ret = -1;
+  if(filename && !g_file_test(filename, G_FILE_TEST_IS_DIR))
+    return (open_for_real(filename, Denemo.project, template, type));
+  
+  GtkWidget *file_selection;
+  GtkFileFilter *filter;
+  gint i;
+  
+  file_selection = gtk_file_chooser_dialog_new (_(message),
+                        GTK_WINDOW (Denemo.window),
+                        GTK_FILE_CHOOSER_ACTION_OPEN,
+                        GTK_STOCK_CANCEL,
+                        GTK_RESPONSE_REJECT,
+                        GTK_STOCK_OPEN,
+                        GTK_RESPONSE_ACCEPT, NULL);
+  /* Open the last visited directory, if any. */
+  set_current_folder(file_selection, template);
+  
+  filter = gtk_file_filter_new ();
+  gtk_file_filter_set_name (filter, FORMAT_DESCRIPTION(save_type));
+  
+  GList* exts = supported_file_extensions (format); 
+  GList* cur = NULL; 
+  for (cur = exts; cur; cur = cur->next)
+    gtk_file_filter_add_pattern (filter, cur->data); 
+  gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (file_selection), filter);
+  gtk_dialog_set_default_response (GTK_DIALOG (file_selection),
+                   GTK_RESPONSE_ACCEPT);
+  gtk_widget_show_all (file_selection);
+  GtkWidget *preview;
+  preview = gtk_image_new();
+  gtk_file_chooser_set_preview_widget(GTK_FILE_CHOOSER (file_selection), preview);
+  g_signal_connect (GTK_FILE_CHOOSER(file_selection), "update-preview",
+            G_CALLBACK (update_preview_cb), preview);
+  gtk_widget_show_all (preview);
+  if (gtk_dialog_run (GTK_DIALOG (file_selection)) == GTK_RESPONSE_ACCEPT)
+    {
+      gchar *name = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (file_selection));
+      if((ret=open_for_real (name, Denemo.project, template, type))) {
+        gchar *warning = g_strdup_printf(_("Load of file %s failed"), name);
+        warningdialog(warning);
+        g_free(warning);
+      }
+      g_free (name);
+    }
+  gtk_widget_destroy (file_selection);
+  return ret;
+}
 
 /**
  * File open dialog - opened where appropriate 
@@ -875,16 +894,13 @@ update_preview_cb (GtkFileChooser * file_chooser, gpointer data)
 static gint
 file_open (DenemoProject * gui, DenemoSaveType template, ImportType type, gchar * filename)
 {
-FILE_OPEN_DIALOG ("Open", denemo, DENEMO_FORMAT)}
+  return file_open_dialog ("Open", "denemo", DENEMO_FORMAT, template, type, filename);
+}
 
 gint
 open_source_file (void)
 {
-  gchar *filename = NULL;
-  ImportType type = 0;
-  DenemoSaveType template = 0;
-  DenemoProject *gui = Denemo.project;
-  FILE_OPEN_DIALOG ("Open", evince, PDF_FORMAT);
+  return file_open_dialog ("Open", "evince", PDF_FORMAT, 0, 0, NULL);
 }
 
 /**
@@ -895,7 +911,8 @@ open_source_file (void)
 static gint
 file_import_lilypond (DenemoProject * gui, DenemoSaveType template, ImportType type, gchar * filename)
 {
-FILE_OPEN_DIALOG ("Import Lilypond", lilypond, MUDELA_FORMAT)}
+  return file_open_dialog ("Import Lilypond", "lilypond", MUDELA_FORMAT, template, type, filename);
+}
 
 /**
  * Midi Import dialog - opened where appropriate 
@@ -905,8 +922,8 @@ FILE_OPEN_DIALOG ("Import Lilypond", lilypond, MUDELA_FORMAT)}
 static gint
 file_import_midi (DenemoProject * gui, DenemoSaveType template, ImportType type, gchar * filename)
 {
-    
-FILE_OPEN_DIALOG ("Import Midi", midi, MIDI_FORMAT)}
+  return file_open_dialog ("Import Midi", "midi", MIDI_FORMAT, template, type, filename);
+}
 
 /**
  * MusicXML Import dialog - opened where appropriate 
@@ -916,7 +933,8 @@ FILE_OPEN_DIALOG ("Import Midi", midi, MIDI_FORMAT)}
 static gint
 file_import_musicxml (DenemoProject * gui, DenemoSaveType template, ImportType type, gchar * filename)
 {
-FILE_OPEN_DIALOG ("Import MusicXML", musicxml, MUSICXML_FORMAT)}
+  return file_open_dialog ("Import MusicXML", "musicxml", MUSICXML_FORMAT, template, type, filename);
+}
 
 /**
  * Wrapper function to save the current file if not already 
@@ -1256,18 +1274,17 @@ paste_clipboard (GtkAction * action, DenemoScriptParam * param)
 
 }
 
-#define EXPORT_INTERFACE(format_id) \
-  GET_1PARAM(action, param, filename); \
-  DenemoProject *gui = Denemo.project; \
-  if (filename==NULL) \
-    file_export(format_id); \
-  else \
-    if (action==NULL || replace_existing_file_dialog \
-       (filename, format_id)){ \
-      filesel_save (gui, filename, format_id, SAVE_COPY); \
-      force_lily_refresh(gui); \
+static void
+export_interface(GtkAction* action, DenemoScriptParam* param, gint format_id){
+  GET_1PARAM(action, param, filename);
+  if (filename==NULL)
+    file_export(format_id);
+  else
+    if (action==NULL || replace_existing_file_dialog(filename, format_id)){
+      filesel_save (Denemo.project, filename, format_id, SAVE_COPY);
+      force_lily_refresh(Denemo.project);
     }
-
+}
 
 /**
  * Export mudela callback prompts for filename
@@ -1276,7 +1293,8 @@ paste_clipboard (GtkAction * action, DenemoScriptParam * param)
 void
 export_mudela_action (GtkAction * action, DenemoScriptParam * param)
 {
-EXPORT_INTERFACE (MUDELA_FORMAT)}
+  export_interface (action, param, MUDELA_FORMAT);
+}
 
 /**
  * Export pdf callback prompts for filename
@@ -1285,7 +1303,8 @@ EXPORT_INTERFACE (MUDELA_FORMAT)}
 void
 export_pdf_action (GtkAction * action, DenemoScriptParam * param)
 {
-EXPORT_INTERFACE (PDF_FORMAT)}
+  export_interface (action, param, PDF_FORMAT);
+}
 
 /**
  * Export pdf callback prompts for filename
@@ -1294,7 +1313,8 @@ EXPORT_INTERFACE (PDF_FORMAT)}
 void
 export_png_action (GtkAction * action, DenemoScriptParam * param)
 {
-EXPORT_INTERFACE (PNG_FORMAT)}
+  export_interface (action, param, PNG_FORMAT);
+}
 
 /**
  * Export ABC callback prompts for filename
@@ -1303,7 +1323,8 @@ EXPORT_INTERFACE (PNG_FORMAT)}
 void
 export_ABC_action (GtkAction * action, DenemoScriptParam * param)
 {
-EXPORT_INTERFACE (ABC_FORMAT)}
+  export_interface (action, param, ABC_FORMAT);
+}
 
 /**
  * Export MIDI callback prompts for filename
@@ -1312,4 +1333,5 @@ EXPORT_INTERFACE (ABC_FORMAT)}
 void
 export_midi_action (GtkAction * action, DenemoScriptParam * param)
 {
-EXPORT_INTERFACE (MIDI_FORMAT)}
+  export_interface (action, param, MIDI_FORMAT);
+}
