@@ -135,6 +135,7 @@ SCM scheme_change_chord_notes (SCM);
 SCM scheme_put_note_name (SCM);
 SCM scheme_set_accidental (SCM);
 SCM scheme_put_rest (SCM);
+SCM scheme_put_note (SCM);
 SCM scheme_insert_note_in_chord (SCM);
 SCM scheme_diatonic_shift (SCM);
 SCM scheme_next_object (void);
@@ -284,6 +285,12 @@ SCM scheme_select_next_layout (void);
 SCM scheme_select_first_layout (void);
 SCM scheme_select_next_custom_layout (void);
 SCM scheme_select_first_custom_layout (void);
+SCM scheme_get_filename (void);
+SCM scheme_path_from_filename (SCM);
+SCM scheme_file_exists (SCM);
+SCM scheme_filename_from_path (SCM);
+SCM scheme_choose_file (SCM, SCM, SCM);
+SCM scheme_edit_graphics (SCM, SCM);
 SCM scheme_open_source (SCM);
 SCM scheme_export_recorded_audio (void);
 SCM scheme_open_source_file (SCM);
@@ -304,6 +311,7 @@ SCM scheme_get_menu_path (SCM);
 SCM scheme_get_checksum (SCM);
 SCM scheme_set_newbie (SCM);
 SCM scheme_synchronize_lyric_cursor (void);
+SCM scheme_insert_text_in_verse (SCM);
 SCM scheme_get_verse (SCM);
 SCM scheme_put_verse (SCM);
 SCM scheme_append_to_verse (SCM);
